/*--------------------------------------------------------------------
 * $Id: cldprp.c,v 1.5 2001/06/20 14:30:58 pa2h Exp $
 * 
 * This file is part of libRadtran.
 * Copyright (c) 1997-2001 by Arve Kylling and Bernhard Mayer.
 * 
 * ######### Contact info: http://www.libradtran.org #########
 *
 * This program is free software; you can redistribute it and/or 
 * modify it under the terms of the GNU General Public License   
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.        
 * 
 * This program is distributed in the hope that it will be useful, 
 * but WITHOUT ANY WARRANTY; without even the implied warranty of  
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the   
 * GNU General Public License for more details.                    
 * 
 * You should have received a copy of the GNU General Public License          
 * along with this program; if not, write to the Free Software                
 * Foundation, Inc., 59 Temple Place - Suite 330, 
 * Boston, MA 02111-1307, USA.
 *--------------------------------------------------------------------*/

#include <ascii.h>
#include <numeric.h>
#include <getopt.h>
#include "../src_f/f77-uscore.h"


#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <math.h>

#define PROGRAM "CLDPRP"
#define VERSION "0.80a"
#define DATE    "October 26, 2000"



static void print_usage (char *name)
{
  fprintf (stderr, "usage:   %s  <input file>\n", name);
  fprintf (stderr, "%s calculates optical properties of water clouds\n", PROGRAM);
  fprintf (stderr,"according to Hu and Stamnes [1993].\n\n");
  fprintf (stderr, "Required arguments:\n");
  fprintf (stderr, "  The input file is a three-column file with wavelength [nm],\n");
  fprintf (stderr, "  liquid water content [g/m3], and effective droplet radius [um]\n\n");
  fprintf (stderr, "Optional arguments:\n");
  fprintf (stderr, "  -h            Show this help page\n\n");
  fprintf (stderr, "The output is six-columns: wavelength [nm],\n");
  fprintf (stderr, "liquid water content [g/m3], effective droplet radius [um],\n");
  fprintf (stderr, "the extinction coefficient [1/km], the asymmetry parameter,\n");
  fprintf (stderr, "and the single scattering albedo.\n\n");
  
}




/*************************************************************/
/* parse command line options                                */
/*************************************************************/

static int get_options (int argc, char **argv,
			char *programname,
			char *infilename)
{
  int c=0;

  /* reset parameters */
  strcpy (infilename, "");

  /* save name of program */
  strncpy (programname, argv[0], FILENAME_MAX);
  
  

  while ((c=getopt (argc, argv, "h")) != EOF)  {
    switch(c)  {
    case 'h':  /* help */
    case '?':
    default:
      print_usage (programname);
      return (-1);
    }
  }
      
  /* check number of remaining command line arguments */
  if (argc - optind != 1)  {
    print_usage (argv[0]);
    return -1;
  }

  strcpy (infilename, argv[optind]);

  return 0;  /* if o.k. */
}





int main (int argc, char **argv)
{
  int i=0, status=0;
  char path[FILENAME_MAX]="";
  int npath;

  float *wvl=NULL, *lwc=NULL, *reff=NULL;
  int n=0;

  void  F77_FCN (wcloud) (float* lambda_t, int* newsiz, int* nlyr,
			  char* filepath, int* nstring, float* wccon, float* wceffr, 
			  float* tmp_wc_dtau, float* tmp_wc_gg, float* tmp_wc_ssa, float* zd,
			  int *wclyr);


  char programname[FILENAME_MAX], infilename[FILENAME_MAX];

  int newsiz=1, nlyr=1, wclayer=1;
  float tau=0, gg=0, ssa=0;

  float zd[2]    = {1.0, 0.0};
  float effr[2]  = {0.0, 0.0};
  float wccon[2] = {0.0, 0.0};

  /* get command line options */
  status = get_options (argc, argv,
			programname, infilename);
  
  if (status!=0)
    return status;
  

  fprintf (stderr, " ... reading data from %s\n", infilename);

  /* read wavelength file */
  status = read_3c_file_float (infilename, &wvl, &lwc, &reff, &n);

  if (status!=0) {
    fprintf (stderr, "Error %d reading %s\n", status, infilename);
    return status;
  }


  strcpy (path, "../data/");
  npath = strlen(path);

  for (i=0; i<n; i++) {
    effr[1]  = reff[i];
    wccon[1] = lwc[i];


    F77_FCN (wcloud) (&(wvl[i]), &newsiz, &nlyr,
			path, &npath, wccon, effr, 
			&tau, &gg, &ssa, 
			zd, &wclayer);

    fprintf (stdout, "%g %g %g %g %g %g\n", wvl[i], lwc[i], reff[i], tau, gg, ssa);
  }


  return 0;
}
